==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/ASFOUNDTESTPOINTSDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour ASFOUNDTESTPOINTSDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="ASFOUNDTESTPOINTSDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDSTANDARDVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDSTANDARDVALUEUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDOUTPUTVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDOUTPUTVALUEUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDDEVICETOLERANCEFROM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDDEVICETOLERANCETO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDDEVICEREADING" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDDEVIATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDSTATUS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASFOUNDTESTPOINTSDETAILS_Type", propOrder = {
    "asfoundstandardvalue",
    "asfoundstandardvalueuom",
    "asfoundoutputvalue",
    "asfoundoutputvalueuom",
    "asfounddevicetolerancefrom",
    "asfounddevicetoleranceto",
    "asfounddevicereading",
    "asfounddeviation",
    "asfoundstatus"
})
public class ASFOUNDTESTPOINTSDETAILS_Type {

    @XmlElement(name = "ASFOUNDSTANDARDVALUE")
    protected QUANTITY asfoundstandardvalue;
    @XmlElement(name = "ASFOUNDSTANDARDVALUEUOM")
    protected UOMID_Type asfoundstandardvalueuom;
    @XmlElement(name = "ASFOUNDOUTPUTVALUE")
    protected QUANTITY asfoundoutputvalue;
    @XmlElement(name = "ASFOUNDOUTPUTVALUEUOM")
    protected UOMID_Type asfoundoutputvalueuom;
    @XmlElement(name = "ASFOUNDDEVICETOLERANCEFROM")
    protected QUANTITY asfounddevicetolerancefrom;
    @XmlElement(name = "ASFOUNDDEVICETOLERANCETO")
    protected QUANTITY asfounddevicetoleranceto;
    @XmlElement(name = "ASFOUNDDEVICEREADING")
    protected QUANTITY asfounddevicereading;
    @XmlElement(name = "ASFOUNDDEVIATION")
    protected QUANTITY asfounddeviation;
    @XmlElement(name = "ASFOUNDSTATUS")
    protected STATUS_Type asfoundstatus;

    /**
     * Obtient la valeur de la propriété asfoundstandardvalue.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASFOUNDSTANDARDVALUE() {
        return asfoundstandardvalue;
    }

    /**
     * Définit la valeur de la propriété asfoundstandardvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASFOUNDSTANDARDVALUE(QUANTITY value) {
        this.asfoundstandardvalue = value;
    }

    /**
     * Obtient la valeur de la propriété asfoundstandardvalueuom.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getASFOUNDSTANDARDVALUEUOM() {
        return asfoundstandardvalueuom;
    }

    /**
     * Définit la valeur de la propriété asfoundstandardvalueuom.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setASFOUNDSTANDARDVALUEUOM(UOMID_Type value) {
        this.asfoundstandardvalueuom = value;
    }

    /**
     * Obtient la valeur de la propriété asfoundoutputvalue.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASFOUNDOUTPUTVALUE() {
        return asfoundoutputvalue;
    }

    /**
     * Définit la valeur de la propriété asfoundoutputvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASFOUNDOUTPUTVALUE(QUANTITY value) {
        this.asfoundoutputvalue = value;
    }

    /**
     * Obtient la valeur de la propriété asfoundoutputvalueuom.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getASFOUNDOUTPUTVALUEUOM() {
        return asfoundoutputvalueuom;
    }

    /**
     * Définit la valeur de la propriété asfoundoutputvalueuom.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setASFOUNDOUTPUTVALUEUOM(UOMID_Type value) {
        this.asfoundoutputvalueuom = value;
    }

    /**
     * Obtient la valeur de la propriété asfounddevicetolerancefrom.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASFOUNDDEVICETOLERANCEFROM() {
        return asfounddevicetolerancefrom;
    }

    /**
     * Définit la valeur de la propriété asfounddevicetolerancefrom.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASFOUNDDEVICETOLERANCEFROM(QUANTITY value) {
        this.asfounddevicetolerancefrom = value;
    }

    /**
     * Obtient la valeur de la propriété asfounddevicetoleranceto.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASFOUNDDEVICETOLERANCETO() {
        return asfounddevicetoleranceto;
    }

    /**
     * Définit la valeur de la propriété asfounddevicetoleranceto.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASFOUNDDEVICETOLERANCETO(QUANTITY value) {
        this.asfounddevicetoleranceto = value;
    }

    /**
     * Obtient la valeur de la propriété asfounddevicereading.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASFOUNDDEVICEREADING() {
        return asfounddevicereading;
    }

    /**
     * Définit la valeur de la propriété asfounddevicereading.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASFOUNDDEVICEREADING(QUANTITY value) {
        this.asfounddevicereading = value;
    }

    /**
     * Obtient la valeur de la propriété asfounddeviation.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASFOUNDDEVIATION() {
        return asfounddeviation;
    }

    /**
     * Définit la valeur de la propriété asfounddeviation.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASFOUNDDEVIATION(QUANTITY value) {
        this.asfounddeviation = value;
    }

    /**
     * Obtient la valeur de la propriété asfoundstatus.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getASFOUNDSTATUS() {
        return asfoundstatus;
    }

    /**
     * Définit la valeur de la propriété asfoundstatus.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setASFOUNDSTATUS(STATUS_Type value) {
        this.asfoundstatus = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/ASFOUNDTESTPOINTSDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for ASFOUNDTESTPOINTSDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ASFOUNDTESTPOINTSDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDSTANDARDVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDSTANDARDVALUEUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDOUTPUTVALUE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDOUTPUTVALUEUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDDEVICETOLERANCEFROM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDDEVICETOLERANCETO" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDDEVICEREADING" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDDEVIATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASFOUNDSTATUS" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ASFOUNDTESTPOINTSDETAILS_Type", propOrder = {
    "asfoundstandardvalue",
    "asfoundstandardvalueuom",
    "asfoundoutputvalue",
    "asfoundoutputvalueuom",
    "asfounddevicetolerancefrom",
    "asfounddevicetoleranceto",
    "asfounddevicereading",
    "asfounddeviation",
    "asfoundstatus"
})
public class ASFOUNDTESTPOINTSDETAILS_Type {

    @XmlElement(name = "ASFOUNDSTANDARDVALUE")
    protected QUANTITY asfoundstandardvalue;
    @XmlElement(name = "ASFOUNDSTANDARDVALUEUOM")
    protected UOMID_Type asfoundstandardvalueuom;
    @XmlElement(name = "ASFOUNDOUTPUTVALUE")
    protected QUANTITY asfoundoutputvalue;
    @XmlElement(name = "ASFOUNDOUTPUTVALUEUOM")
    protected UOMID_Type asfoundoutputvalueuom;
    @XmlElement(name = "ASFOUNDDEVICETOLERANCEFROM")
    protected QUANTITY asfounddevicetolerancefrom;
    @XmlElement(name = "ASFOUNDDEVICETOLERANCETO")
    protected QUANTITY asfounddevicetoleranceto;
    @XmlElement(name = "ASFOUNDDEVICEREADING")
    protected QUANTITY asfounddevicereading;
    @XmlElement(name = "ASFOUNDDEVIATION")
    protected QUANTITY asfounddeviation;
    @XmlElement(name = "ASFOUNDSTATUS")
    protected STATUS_Type asfoundstatus;

    /**
     * Gets the value of the asfoundstandardvalue property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASFOUNDSTANDARDVALUE() {
        return asfoundstandardvalue;
    }

    /**
     * Sets the value of the asfoundstandardvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASFOUNDSTANDARDVALUE(QUANTITY value) {
        this.asfoundstandardvalue = value;
    }

    /**
     * Gets the value of the asfoundstandardvalueuom property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getASFOUNDSTANDARDVALUEUOM() {
        return asfoundstandardvalueuom;
    }

    /**
     * Sets the value of the asfoundstandardvalueuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setASFOUNDSTANDARDVALUEUOM(UOMID_Type value) {
        this.asfoundstandardvalueuom = value;
    }

    /**
     * Gets the value of the asfoundoutputvalue property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASFOUNDOUTPUTVALUE() {
        return asfoundoutputvalue;
    }

    /**
     * Sets the value of the asfoundoutputvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASFOUNDOUTPUTVALUE(QUANTITY value) {
        this.asfoundoutputvalue = value;
    }

    /**
     * Gets the value of the asfoundoutputvalueuom property.
     * 
     * @return
     *     possible object is
     *     {@link UOMID_Type }
     *     
     */
    public UOMID_Type getASFOUNDOUTPUTVALUEUOM() {
        return asfoundoutputvalueuom;
    }

    /**
     * Sets the value of the asfoundoutputvalueuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link UOMID_Type }
     *     
     */
    public void setASFOUNDOUTPUTVALUEUOM(UOMID_Type value) {
        this.asfoundoutputvalueuom = value;
    }

    /**
     * Gets the value of the asfounddevicetolerancefrom property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASFOUNDDEVICETOLERANCEFROM() {
        return asfounddevicetolerancefrom;
    }

    /**
     * Sets the value of the asfounddevicetolerancefrom property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASFOUNDDEVICETOLERANCEFROM(QUANTITY value) {
        this.asfounddevicetolerancefrom = value;
    }

    /**
     * Gets the value of the asfounddevicetoleranceto property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASFOUNDDEVICETOLERANCETO() {
        return asfounddevicetoleranceto;
    }

    /**
     * Sets the value of the asfounddevicetoleranceto property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASFOUNDDEVICETOLERANCETO(QUANTITY value) {
        this.asfounddevicetoleranceto = value;
    }

    /**
     * Gets the value of the asfounddevicereading property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASFOUNDDEVICEREADING() {
        return asfounddevicereading;
    }

    /**
     * Sets the value of the asfounddevicereading property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASFOUNDDEVICEREADING(QUANTITY value) {
        this.asfounddevicereading = value;
    }

    /**
     * Gets the value of the asfounddeviation property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getASFOUNDDEVIATION() {
        return asfounddeviation;
    }

    /**
     * Sets the value of the asfounddeviation property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setASFOUNDDEVIATION(QUANTITY value) {
        this.asfounddeviation = value;
    }

    /**
     * Gets the value of the asfoundstatus property.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getASFOUNDSTATUS() {
        return asfoundstatus;
    }

    /**
     * Sets the value of the asfoundstatus property.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setASFOUNDSTATUS(STATUS_Type value) {
        this.asfoundstatus = value;
    }

}
